==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/lt_LT.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Žymės",
    "Update" : "Atnaujinti",
    "Create" : "Pridėti",
    "Select tag…" : "Pasirinkti žymę...",
    "Select tags to filter by" : "Pasirinkite žymes, pagal kurias filtruoti",
    "No tags found" : "Nerasta jokių žymių",
    "Please select tags to filter by" : "Prašome pasirinkti žymes, pagal kurias filtruoti",
    "No files found for the selected tags" : "Pasirinktai žymei, nerasti jokie failai.",
    "Added system tag %1$s" : "Pridėta sistemos žymė %1$s",
    "Added system tag {systemtag}" : "Pridėta sistemos žymė {systemtag}",
    "%1$s added system tag %2$s" : "%1$s pridėjo sistemos žymę %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridėjo sistemos žymę {systemtag}",
    "Removed system tag %1$s" : "Pašalinta sistemos žymė %1$s",
    "Removed system tag {systemtag}" : "Pašalinta sistemos žymė {systemtag}",
    "%1$s removed system tag %2$s" : "%1$s pašalino sistemos žymę %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} pašalino sistemos žymę {systemtag}",
    "You created system tag %1$s" : "Jūs sukūrėte sistemos žymę %1$s",
    "You created system tag {systemtag}" : "Jūs sukūrėte sistemos žymę {systemtag}",
    "%1$s created system tag %2$s" : "%1$s sukūrė sistemos žymę %2$s",
    "{actor} created system tag {systemtag}" : "{actor} sukūrė sistemos žymę {systemtag}",
    "You deleted system tag %1$s" : "Jūs ištrynėte sistemos žymę %1$s",
    "You deleted system tag {systemtag}" : "Jūs ištrynėte sistemos žymę {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ištrynė sistemos žymę %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ištrynė sistemos žymę {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atnaujinote sistemos žymę %2$s į %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atnaujinote sistemos žymę {oldsystemtag} į {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atnaujino sistemos žymę %3$s į %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atnaujino sistemos žymę {oldsystemtag} į {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Jūs pridėjote sistemos žymę %2$s prie %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pridėjote sistemos žymę {systemtag} prie {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s pridėjo sistemos žymę %3$s prie %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pridėjo sistemos žymę {systemtag} prie {file}",
    "You removed system tag %2$s from %1$s" : "Jūs pašalinote sistemos žymę %2$s nuo %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs pašalinote sistemos žymę {systemtag} nuo {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s pašalino sistemos žymę %3$s nuo %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} pašalino sistemos žymę {systemtag} nuo {file}",
    "%s (restricted)" : "%s (ribota)",
    "%s (invisible)" : "%s (nematoma)",
    "<strong>System tags</strong> for a file have been modified" : "Failo <strong>sistemos žymės</strong> buvo pakeistos.",
    "Collaborative tags" : "Žymės",
    "Select tag …" : "Pasirinkite žymę…",
    "Create a new tag" : "Sukurti naują žymę",
    "Name" : "Pavadinimas",
    "Public" : "Vieša",
    "Restricted" : "Riboto naudojimo",
    "Invisible" : "Nematoma",
    "Delete" : "Ištrinti",
    "Reset" : "Atstatyti",
    "No files in here" : "Aplankas tuščias",
    "No entries found in this folder" : "Aplankas tuščias",
    "Size" : "Dydis",
    "Modified" : "Pakeista",
    "Create and edit collaborative tags. These tags affect all users." : "Bendrų žymių visiems sistemos vartotojams kūrimas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/lt_LT.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Žymės",
    "Update" : "Atnaujinti",
    "Create" : "Sukurti",
    "Select tag…" : "Pasirinkti žymę...",
    "Tagged files" : "Pažymėti failai",
    "Select tags to filter by" : "Pasirinkite žymes, pagal kurias filtruoti",
    "No tags found" : "Nerasta jokių žymių",
    "Please select tags to filter by" : "Prašome pasirinkti žymes, pagal kurias filtruoti",
    "No files found for the selected tags" : "Pasirinktai žymei, nerasti jokie failai.",
    "System tag %1$s added by the system" : "Sistema pridėjo sistemos žymę %1$s",
    "Added system tag {systemtag}" : "Pridėta sistemos žymė {systemtag}",
    "Added system tag %1$s" : "Pridėta sistemos žymė %1$s",
    "%1$s added system tag %2$s" : "%1$s pridėjo sistemos žymę %2$s",
    "{actor} added system tag {systemtag}" : "{actor} pridėjo sistemos žymę {systemtag}",
    "System tag %1$s removed by the system" : "Sistema pašalino sistemos žymę %1$s",
    "Removed system tag {systemtag}" : "Pašalinta sistemos žymė {systemtag}",
    "Removed system tag %1$s" : "Pašalinta sistemos žymė %1$s",
    "%1$s removed system tag %2$s" : "%1$s pašalino sistemos žymę %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} pašalino sistemos žymę {systemtag}",
    "You created system tag %1$s" : "Jūs sukūrėte sistemos žymę %1$s",
    "You created system tag {systemtag}" : "Jūs sukūrėte sistemos žymę {systemtag}",
    "%1$s created system tag %2$s" : "%1$s sukūrė sistemos žymę %2$s",
    "{actor} created system tag {systemtag}" : "{actor} sukūrė sistemos žymę {systemtag}",
    "You deleted system tag %1$s" : "Jūs ištrynėte sistemos žymę %1$s",
    "You deleted system tag {systemtag}" : "Jūs ištrynėte sistemos žymę {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s ištrynė sistemos žymę %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} ištrynė sistemos žymę {systemtag}",
    "You updated system tag %2$s to %1$s" : "Jūs atnaujinote sistemos žymę %2$s į %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Jūs atnaujinote sistemos žymę {oldsystemtag} į {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s atnaujino sistemos žymę %3$s į %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} atnaujino sistemos žymę {oldsystemtag} į {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Jūs pridėjote sistemos žymę %2$s prie %1$s",
    "You added system tag {systemtag} to {file}" : "Jūs pridėjote sistemos žymę {systemtag} prie {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s pridėjo sistemos žymę %3$s prie %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} pridėjo sistemos žymę {systemtag} prie {file}",
    "You removed system tag %2$s from %1$s" : "Jūs pašalinote sistemos žymę %2$s nuo %1$s",
    "You removed system tag {systemtag} from {file}" : "Jūs pašalinote sistemos žymę {systemtag} nuo {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s pašalino sistemos žymę %3$s nuo %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} pašalino sistemos žymę {systemtag} nuo {file}",
    "<strong>System tags</strong> for a file have been modified" : "Failo <strong>sistemos žymės</strong> buvo pakeistos.",
    "Select tag …" : "Pasirinkite žymę…",
    "Create a new tag" : "Sukurti naują žymę",
    "Name" : "Pavadinimas",
    "Public" : "Vieša",
    "Invisible" : "Nematoma",
    "Delete" : "Ištrinti",
    "Reset" : "Atstatyti",
    "No files in here" : "Čia failų nėra",
    "No entries found in this folder" : "Šiame aplanke nerasta jokių įrašų",
    "Size" : "Dydis",
    "Modified" : "Pakeista"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
